<?php
/**
 * Real Estate Services: Customizer
 *
 * @subpackage Real Estate Services
 * @since 1.0
 */

use WPTRT\Customize\Section\Luzuk_Real_Estate_Services_Button;

add_action( 'customize_register', function( $manager ) {

	$manager->register_section_type( Luzuk_Real_Estate_Services_Button::class );

	$manager->add_section(
		new Luzuk_Real_Estate_Services_Button( $manager, 'luzuk_real_estate_services_pro', [
			'title' => __( 'Real Estate Services Pro', 'real-estate-services' ),
			'priority' => 0,
			'button_text' => __( 'Go Pro', 'real-estate-services' ),
			'button_url'  => esc_url( 'https://www.luzuk.com/product/real-estate-wp-theme/', 'real-estate-services')
		] )
	);

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

	$version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script(
		'real-estate-services-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
		[ 'customize-controls' ],
		$version,
		true
	);

	wp_enqueue_style(
		'real-estate-services-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
		[ 'customize-controls' ],
 		$version
	);

} );

function luzuk_real_estate_services_customize_register( $wp_customize ) {

	$wp_customize->add_setting('luzuk_real_estate_services_logo_size',array(
		'sanitize_callback'	=> 'luzuk_real_estate_services_sanitize_float'
	));
	$wp_customize->add_control('luzuk_real_estate_services_logo_size',array(
		'type' => 'range',
		'label' => __('Logo Size','real-estate-services'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('luzuk_real_estate_services_logo_padding',array(
		'sanitize_callback'	=> 'esc_html'
	));
	$wp_customize->add_control('luzuk_real_estate_services_logo_padding',array(
		'label' => __('Logo Margin','real-estate-services'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('luzuk_real_estate_services_logo_top_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_real_estate_services_sanitize_float'
	));
	$wp_customize->add_control('luzuk_real_estate_services_logo_top_padding',array(
		'type' => 'number',
		'description' => __('Top','real-estate-services'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_logo_bottom_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_real_estate_services_sanitize_float'
	));
	$wp_customize->add_control('luzuk_real_estate_services_logo_bottom_padding',array(
		'type' => 'number',
		'description' => __('Bottom','real-estate-services'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_logo_left_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_real_estate_services_sanitize_float'
	));
	$wp_customize->add_control('luzuk_real_estate_services_logo_left_padding',array(
		'type' => 'number',
		'description' => __('Left','real-estate-services'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_logo_right_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_real_estate_services_sanitize_float'
 	));
 	$wp_customize->add_control('luzuk_real_estate_services_logo_right_padding',array(
		'type' => 'number',
		'description' => __('Right','real-estate-services'),
		'section' => 'title_tagline',
    ));

	$wp_customize->add_setting('luzuk_real_estate_services_show_site_title',array(
		'default' => true,
		'sanitize_callback'	=> 'luzuk_real_estate_services_sanitize_checkbox'
	));
	$wp_customize->add_control('luzuk_real_estate_services_show_site_title',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Title','real-estate-services'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting( 'luzuk_real_estate_services_site_title_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_site_title_color', array(
		'label' => 'Title Color',
		'section' => 'title_tagline',
	)));

	$wp_customize->add_setting('luzuk_real_estate_services_show_tagline',array(
		'default' => true,
		'sanitize_callback'	=> 'luzuk_real_estate_services_sanitize_checkbox'
	));
	$wp_customize->add_control('luzuk_real_estate_services_show_tagline',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Tagline','real-estate-services'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting( 'luzuk_real_estate_services_site_tagline_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_site_tagline_color', array(
		'label' => 'Tagline Color',
		'section' => 'title_tagline',
	)));

	$wp_customize->add_panel( 'luzuk_real_estate_services_panel_id', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Theme Settings', 'real-estate-services' ),
		'description' => __( 'Description of what this panel does.', 'real-estate-services' ),
	) );

	$wp_customize->add_section( 'luzuk_real_estate_services_theme_options_section', array(
    	'title'      => __( 'General Settings', 'real-estate-services' ),
		'priority'   => 30,
		'panel' => 'luzuk_real_estate_services_panel_id'
	) );

	$wp_customize->add_setting('luzuk_real_estate_services_theme_options',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_real_estate_services_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_real_estate_services_theme_options',array(
		'type' => 'select',
		'label' => __('Blog Page Sidebar Layout','real-estate-services'),
		'section' => 'luzuk_real_estate_services_theme_options_section',
		'choices' => array(
		   'Left Sidebar' => __('Left Sidebar','real-estate-services'),
		   'Right Sidebar' => __('Right Sidebar','real-estate-services'),
		   'One Column' => __('One Column','real-estate-services'),
		   'Grid Layout' => __('Grid Layout','real-estate-services')
		),
	));

	$wp_customize->add_setting('luzuk_real_estate_services_single_post_sidebar',array(
		'default' => 'Right Sidebar',
		'sanitize_callback' => 'luzuk_real_estate_services_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_real_estate_services_single_post_sidebar',array(
        'type' => 'select',
        'label' => __('Single Post Sidebar Layout','real-estate-services'),
        'section' => 'luzuk_real_estate_services_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','real-estate-services'),
            'Right Sidebar' => __('Right Sidebar','real-estate-services'),
            'One Column' => __('One Column','real-estate-services')
        ),
	));

	$wp_customize->add_setting('luzuk_real_estate_services_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_real_estate_services_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_real_estate_services_page_sidebar',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','real-estate-services'),
        'section' => 'luzuk_real_estate_services_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','real-estate-services'),
            'Right Sidebar' => __('Right Sidebar','real-estate-services'),
            'One Column' => __('One Column','real-estate-services')
        ),
	));

	$wp_customize->add_setting('luzuk_real_estate_services_archive_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_real_estate_services_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_real_estate_services_archive_page_sidebar',array(
        'type' => 'select',
        'label' => __('Archive & Search Page Sidebar Layout','real-estate-services'),
        'section' => 'luzuk_real_estate_services_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','real-estate-services'),
            'Right Sidebar' => __('Right Sidebar','real-estate-services'),
            'One Column' => __('One Column','real-estate-services'),
            'Grid Layout' => __('Grid Layout','real-estate-services')
        ),
	));

	$wp_customize->add_setting( 'luzuk_real_estate_services_boxfull_width', array(
		'default'           => '',
		'sanitize_callback' => 'luzuk_real_estate_services_sanitize_choices'
	));
	
	$wp_customize->add_control( 'luzuk_real_estate_services_boxfull_width', array(
		'label'    => __( 'Section Width', 'real-estate-services' ),
		'section'  => 'luzuk_real_estate_services_theme_options_section',
		'type'     => 'select',
		'choices'  => array(
			'container'  => __('Box Width', 'real-estate-services'),
			'container-fluid' => __('Full Width', 'real-estate-services'),
			'none' => __('None', 'real-estate-services')
		),
	));

	$wp_customize->add_setting( 'luzuk_real_estate_services_dropdown_anim', array(
		'default'           => 'None',
		'sanitize_callback' => 'luzuk_real_estate_services_sanitize_choices'
	));
	$wp_customize->add_control( 'luzuk_real_estate_services_dropdown_anim', array(
		'label'    => __( 'Menu Dropdown Animations', 'real-estate-services' ),
		'section'  => 'luzuk_real_estate_services_theme_options_section',
		'type'     => 'select',
		'choices'  => array(
			'bounceInUp'  => __('bounceInUp', 'real-estate-services'),
			'fadeInUp' => __('fadeInUp', 'real-estate-services'),
			'zoomIn'    => __('zoomIn', 'real-estate-services'),
			'None'    => __('None', 'real-estate-services')
		),
	));
 
	//Header
	$wp_customize->add_section( 'luzuk_real_estate_services_header' , array(
    	'title'    => __( 'Header Settings', 'real-estate-services' ),
		'priority' => null,
		'panel' => 'luzuk_real_estate_services_panel_id'
	) );

	$wp_customize->add_setting('luzuk_real_estate_services_header_mail',array(
		'default' => 'info@yourmail.com',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_header_mail',array(
	   	'type' => 'text',
	   	'label' => __('Mail','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_header',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_fblink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_real_estate_services_fblink',array(
	   	'type' => 'url',
	   	'label' => __('Facebook Icon Link','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_header',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_twitterlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_real_estate_services_twitterlink',array(
	   	'type' => 'url',
	   	'label' => __('Twitter Icon Link','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_header',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_telegramlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_real_estate_services_telegramlink',array(
	   	'type' => 'url',
	   	'label' => __('Telegram Icon Link','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_header',
	));
	
	
	$wp_customize->add_setting('luzuk_real_estate_services_header_btnlink',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_header_btnlink',array(
	   	'type' => 'text',
	   	'label' => __('Button Link','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_header',
	));

	$wp_customize->add_setting( 'luzuk_real_estate_services_headertoptext_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_headertoptext_col', array(
		'label' => 'Top Text Color',
		'section' => 'luzuk_real_estate_services_header',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_headertopicon_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_headertopicon_col', array(
		'label' => 'Top Icon Color',
		'section' => 'luzuk_real_estate_services_header',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_headertoptexthover_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_headertoptexthover_col', array(
		'label' => 'Top Text Hover Color',
		'section' => 'luzuk_real_estate_services_header',
	)));


	$wp_customize->add_setting( 'luzuk_real_estate_services_headertopsocialicon_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_headertopsocialicon_col', array(
		'label' => 'Social Icon BG Color',
		'section' => 'luzuk_real_estate_services_header',
	)));


	$wp_customize->add_setting( 'luzuk_real_estate_services_headertopsocialiconhover_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_headertopsocialiconhover_col', array(
		'label' => 'Social Icon BG Hover Color',
		'section' => 'luzuk_real_estate_services_header',
	)));


	$wp_customize->add_setting( 'luzuk_real_estate_services_menu_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_menu_color', array(
		'label' => 'Menu Color',
		'section' => 'luzuk_real_estate_services_header',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_menuhover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_menuhover_color', array(
		'label' => 'Menu Hover Color',
		'section' => 'luzuk_real_estate_services_header',
	)));


	$wp_customize->add_setting( 'luzuk_real_estate_services_submenu_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_submenu_color', array(
		'label' => 'Submenu Text Color',
		'section' => 'luzuk_real_estate_services_header',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_submenubg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_submenubg_color', array(
		'label' => 'Submenu BG Color',
		'section' => 'luzuk_real_estate_services_header',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_header_btntexticon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_header_btntexticon_color', array(
		'label' => 'Button Text & Icon Color',
		'section' => 'luzuk_real_estate_services_header',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_header_btntexticonbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_header_btntexticonbg_color', array(
		'label' => 'Button BG Color',
		'section' => 'luzuk_real_estate_services_header',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_header_btntexticonhover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_header_btntexticonhover_color', array(
		'label' => 'Button Text & Icon Hover Color',
		'section' => 'luzuk_real_estate_services_header',
	)));

	


	//home page slider
	$wp_customize->add_section( 'luzuk_real_estate_services_slider_section' , array(
    	'title'    => __( 'Slider Settings', 'real-estate-services' ),
		'description'=> __('<b>Note :</b> Please Add Image in 750*700 Ratio.','real-estate-services'),
		'priority' => null,
		'panel' => 'luzuk_real_estate_services_panel_id'
	) );

	$wp_customize->add_setting('luzuk_real_estate_services_slider_hide_show',array(
    	'default' => false,
    	'sanitize_callback'	=> 'luzuk_real_estate_services_sanitize_checkbox'
	));
	$wp_customize->add_control('luzuk_real_estate_services_slider_hide_show',array(
	   	'type' => 'checkbox',
	   	'label' => __('Show / Hide Slider','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_slider_section',
	));

	$wp_customize->add_setting( 'luzuk_real_estate_services_slider_effect', array(
		'default'           => '',
		'sanitize_callback' => 'luzuk_real_estate_services_sanitize_choices'
	));
	$wp_customize->add_control( 'luzuk_real_estate_services_slider_effect', array(
		'label'    => __( 'Onload Transactions Effects', 'real-estate-services' ),
		'section'  => 'luzuk_real_estate_services_slider_section',
		'type'     => 'select',
		'choices'  => array(
			'bounceInLeft'  => __('bounceInLeft', 'real-estate-services'),
			'bounceInRight' => __('bounceInRight', 'real-estate-services'),
			'bounceInUp'    => __('bounceInUp', 'real-estate-services'),
			'bounceInDown'    => __('bounceInDown', 'real-estate-services'),
			'zoomIn'  => __('zoomIn', 'real-estate-services'),
			'zoomOut' => __('zoomOut', 'real-estate-services'),
			'fadeInDown'    => __('fadeInDown', 'real-estate-services'),
			'fadeInUp'    => __('fadeInUp', 'real-estate-services'),
			'fadeInLeft'  => __('fadeInLeft', 'real-estate-services'),
			'fadeInRight' => __('fadeInRight', 'real-estate-services'),
			'flip-up'    => __('flip-up', 'real-estate-services'),
			'none'    => __('none', 'real-estate-services')
		),
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'luzuk_real_estate_services_slider' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'luzuk_real_estate_services_sanitize_dropdown_pages'
		));
		$wp_customize->add_control( 'luzuk_real_estate_services_slider' . $count, array(
			'label' => __('Select Slider Image Page', 'real-estate-services' ),
			'section' => 'luzuk_real_estate_services_slider_section',
			'type' => 'dropdown-pages'
		));
	}


	$wp_customize->add_setting('luzuk_real_estate_services_slider_excerpt_length',array(
		'default' => '15',
		'sanitize_callback'	=> 'luzuk_real_estate_services_sanitize_float'
	));
	$wp_customize->add_control('luzuk_real_estate_services_slider_excerpt_length',array(
		'type' => 'number',
		'label' => __('Description Excerpt Length','real-estate-services'),
		'section' => 'luzuk_real_estate_services_slider_section',
	));


	$wp_customize->add_setting('luzuk_real_estate_services_slider_heading',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_slider_heading',array(
	   	'type' => 'text',
	   	'label' => __('Heading','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_slider_section',
	));


	$wp_customize->add_setting('luzuk_real_estate_services_sliderbtnlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_real_estate_services_sliderbtnlink',array(
	   	'type' => 'url',
	   	'label' => __('Button Link','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_slider_section',
	));


	$wp_customize->add_setting( 'luzuk_real_estate_services_slider_heading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_slider_heading_color', array(
		'label' => 'Heading Color',
		'section' => 'luzuk_real_estate_services_slider_section',
	)));
	

	$wp_customize->add_setting( 'luzuk_real_estate_services_slider_title_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_slider_title_color', array(
		'label' => 'Title Color',
		'section' => 'luzuk_real_estate_services_slider_section',
	)));
	

	$wp_customize->add_setting( 'luzuk_real_estate_services_slider_description_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_slider_description_color', array(
		'label' => 'Description Color',
		'section' => 'luzuk_real_estate_services_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_slider_btntext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_slider_btntext_color', array(
		'label' => 'Button Text Color',
		'section' => 'luzuk_real_estate_services_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_slider_btnbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_slider_btnbg_color', array(
		'label' => 'Button BG Color',
		'section' => 'luzuk_real_estate_services_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_slider_btntexthrv_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_slider_btntexthrv_color', array(
		'label' => 'Button Hover Color',
		'section' => 'luzuk_real_estate_services_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_slider_arrowicon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_slider_arrowicon_color', array(
		'label' => 'Arrow Icon Color',
		'section' => 'luzuk_real_estate_services_slider_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_slider_arrowbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_slider_arrowbg_color', array(
		'label' => 'Arrow BG Color',
		'section' => 'luzuk_real_estate_services_slider_section',
	)));



	// Feature Section
	$wp_customize->add_section('luzuk_real_estate_services_feature_section',array(
		'title'	=> __('Feature Settings','real-estate-services'),
		'description'=> __('<b>Note :</b> This section will appear below the Slider.','real-estate-services'),
		'panel' => 'luzuk_real_estate_services_panel_id',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_featuresubheading',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_featuresubheading',array(
	   	'type' => 'text',
	   	'label' => __('Sub Heading','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_featureheading',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_featureheading',array(
	   	'type' => 'text',
	   	'label' => __('Heading','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feature_exploreallbtnlink',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feature_exploreallbtnlink',array(
	   	'type' => 'text',
	   	'label' => __('Explore All Button Link','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$pages = get_pages(); // Retrieve pages
	$page_options = array(); // Initialize page options array
	foreach ($pages as $page) {
		$page_options[$page->ID] = $page->post_title; // Store page ID and title in options array
	}

	$wp_customize->add_setting('luzuk_real_estate_services_page_setting_1', array(
		'default'            => '',
		'sanitize_callback'  => 'absint', // Use absint to ensure the value is an integer
	));

	$wp_customize->add_control('luzuk_real_estate_services_page_setting_1', array(
		'label'    => __('Select Page 1', 'real-estate-services'),
		'section'  => 'luzuk_real_estate_services_feature_section', 
		'type'     => 'dropdown-pages',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_address_page1',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_address_page1',array(
	   	'type' => 'text',
	   	'label' => __('Page 1 Address','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_dimension_page1',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_dimension_page1',array(
	   	'type' => 'text',
	   	'label' => __('Page 1 Dimension','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_meter_page1',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_meter_page1',array(
	   	'type' => 'text',
	   	'label' => __('Page 1 Meter','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_pricetext_page1',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_pricetext_page1',array(
	   	'type' => 'text',
	   	'label' => __('Page 1 Price Text','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_price_page1',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_price_page1',array(
	   	'type' => 'text',
	   	'label' => __('Page 1 Price','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_page_setting_2', array(
		'default'            => '',
		'sanitize_callback'  => 'absint', // Use absint to ensure the value is an integer
	));

	$wp_customize->add_control('luzuk_real_estate_services_page_setting_2', array(
		'label'    => __('Select Page 2', 'real-estate-services'),
		'section'  => 'luzuk_real_estate_services_feature_section', 
		'type'     => 'dropdown-pages',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_address_page2',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_address_page2',array(
	   	'type' => 'text',
	   	'label' => __('Page 2 Address','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_dimension_page2',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_dimension_page2',array(
	   	'type' => 'text',
	   	'label' => __('Page 2 Dimension','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_meter_page2',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_meter_page2',array(
	   	'type' => 'text',
	   	'label' => __('Page 2 Meter','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_pricetext_page2',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_pricetext_page2',array(
	   	'type' => 'text',
	   	'label' => __('Page 2 Price Text','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_price_page2',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_price_page2',array(
	   	'type' => 'text',
	   	'label' => __('Page 2 Price','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_page_setting_3', array(
		'default'            => '',
		'sanitize_callback'  => 'absint', // Use absint to ensure the value is an integer
	));

	$wp_customize->add_control('luzuk_real_estate_services_page_setting_3', array(
		'label'    => __('Select Page 3', 'real-estate-services'),
		'section'  => 'luzuk_real_estate_services_feature_section', 
		'type'     => 'dropdown-pages',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_address_page3',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_address_page3',array(
	   	'type' => 'text',
	   	'label' => __('Page 3 Address','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_dimension_page3',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_dimension_page3',array(
	   	'type' => 'text',
	   	'label' => __('Page 3 Dimension','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_meter_page3',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_meter_page3',array(
	   	'type' => 'text',
	   	'label' => __('Page 3 Meter','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_pricetext_page3',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_pricetext_page3',array(
	   	'type' => 'text',
	   	'label' => __('Page 3 Price Text','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_feture_price_page3',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_feture_price_page3',array(
	   	'type' => 'text',
	   	'label' => __('Page 3 Price','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_feature_section',
	));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_subheading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_subheading_color', array(
		'label' => 'Sub Heading Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_heading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_heading_color', array(
		'label' => 'Heading Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_exploreall_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_exploreall_color', array(
		'label' => 'Explore All & Icon Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_boxborder_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_boxborder_color', array(
		'label' => 'Box Border Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_location_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_location_color', array(
		'label' => 'Location Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_title_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_title_color', array(
		'label' => 'Title Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_landinfotext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_landinfotext_color', array(
		'label' => 'Land Info Text Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_landinfoicon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_landinfoicon_color', array(
		'label' => 'Land Info Icon Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_btntext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_btntext_color', array(
		'label' => 'Button Text Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_btnbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_btnbg_color', array(
		'label' => 'Button BG Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_pricetext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_pricetext_color', array(
		'label' => 'Price Text Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_feature_price_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_feature_price_color', array(
		'label' => 'Price Color',
		'section' => 'luzuk_real_estate_services_feature_section',
	)));



	// Aboutus Section
	$wp_customize->add_section('luzuk_real_estate_services_aboutus_section',array(
		'title'	=> __('About Us Settings','real-estate-services'),
		'description'=> __('<b>Note :</b> This section will appear below the Product Section.','real-estate-services'),
		'panel' => 'luzuk_real_estate_services_panel_id',
	));


	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_subheading',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_subheading',array(
	   	'type' => 'text',
	   	'label' => __('Sub Heading','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_heading',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_heading',array(
	   	'type' => 'text',
	   	'label' => __('Heading','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_box1icon',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_box1icon',array(
	   	'type' => 'text',
	   	'label' => __('Plan 1 Icon (Like fas fa-handshake)','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_box1heading',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_box1heading',array(
	   	'type' => 'text',
	   	'label' => __('Plan 1 Heading','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_box1description',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_box1description',array(
	   	'type' => 'text',
	   	'label' => __('Plan 1 Description','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));	

	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_box2icon',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_box2icon',array(
	   	'type' => 'text',
	   	'label' => __('Plan 2 Icon (Like fas fa-handshake)','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_box2heading',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_box2heading',array(
	   	'type' => 'text',
	   	'label' => __('Plan 2 Heading','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_box2description',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_box2description',array(
	   	'type' => 'text',
	   	'label' => __('Plan 2 Description','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));	

	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_box3icon',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_box3icon',array(
	   	'type' => 'text',
	   	'label' => __('Plan 3 Icon (Like fas fa-handshake)','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_box3heading',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_box3heading',array(
	   	'type' => 'text',
	   	'label' => __('Plan 3 Heading','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_box3description',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_box3description',array(
	   	'type' => 'text',
	   	'label' => __('Plan 3 Description','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));
	
	$wp_customize->add_setting('luzuk_real_estate_services_aboutus_imgdescription',array(
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_real_estate_services_aboutus_imgdescription',array(
	   	'type' => 'text',
	   	'label' => __('Image Description','real-estate-services'),
	   	'section' => 'luzuk_real_estate_services_aboutus_section',
	));	


	$wp_customize->add_setting(
    	'luzuk_real_estate_services_aboutus_img',
	    array(
	        'sanitize_callback' => 'esc_url_raw'
	    )
	);
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'luzuk_real_estate_services_aboutus_img',
	        array(
			    'label'   		=> __('Image','real-estate-services'),
				'description'   		=> __('Image size 322*491','real-estate-services'),
	            'section' => 'luzuk_real_estate_services_aboutus_section',
	            'settings' => 'luzuk_real_estate_services_aboutus_img',
	        )
	    )
	);

	$wp_customize->add_setting( 'luzuk_real_estate_services_aboutus_subheading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_aboutus_subheading_color', array(
		'label' => 'Sub Heading Color',
		'section' => 'luzuk_real_estate_services_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_aboutus_heading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_aboutus_heading_color', array(
		'label' => 'Heading Color',
		'section' => 'luzuk_real_estate_services_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_aboutus_boxicon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_aboutus_boxicon_color', array(
		'label' => 'Box Icon Color',
		'section' => 'luzuk_real_estate_services_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_aboutus_boxtitle_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_aboutus_boxtitle_color', array(
		'label' => 'Box Title Color',
		'section' => 'luzuk_real_estate_services_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_aboutus_boxdescription_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_aboutus_boxdescription_color', array(
		'label' => 'Box Description Color',
		'section' => 'luzuk_real_estate_services_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_aboutus_imgdecription_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_aboutus_imgdecription_color', array(
		'label' => 'Image Description Color',
		'section' => 'luzuk_real_estate_services_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_aboutus_imgsaletagtext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_aboutus_imgsaletagtext_color', array(
		'label' => 'Image Sale Tag Text Color',
		'section' => 'luzuk_real_estate_services_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_aboutus_imgsaletagbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_aboutus_imgsaletagbg_color', array(
		'label' => 'Image Sale Tag BG Color',
		'section' => 'luzuk_real_estate_services_aboutus_section',
	)));
	


	//Footer
    $wp_customize->add_section( 'luzuk_real_estate_services_footer', array(
    	'title'  => __( 'Footer Settings', 'real-estate-services' ),
		'priority' => null,
		'panel' => 'luzuk_real_estate_services_panel_id'
	) );

	$wp_customize->add_setting('luzuk_real_estate_services_show_back_totop',array(
       'default' => true,
       'sanitize_callback'	=> 'luzuk_real_estate_services_sanitize_checkbox'
    ));
    $wp_customize->add_control('luzuk_real_estate_services_show_back_totop',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Back to Top','real-estate-services'),
       'section' => 'luzuk_real_estate_services_footer'
    ));

    $wp_customize->add_setting('luzuk_real_estate_services_footer_copy', array(
		'default'           => 'Copyright © 2024 Agency Wordpress Themes. All rights reserved.',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('luzuk_real_estate_services_footer_copy', array(
		'label'       => __('Copyright Text', 'real-estate-services'),
		'section'     => 'luzuk_real_estate_services_footer',
		'setting'     => 'luzuk_real_estate_services_footer_copy',
		'type'        => 'text',
		'description' => __('<b>This feature is only available in the premium version.</b>', 'real-estate-services'),
		'input_attrs' => array(
			'readonly' => 'readonly',
		),
	));	

	$wp_customize->add_setting('luzuk_real_estate_services_footer_copylink', array(
		'default'           => 'https://www.luzuk.com/top/wordpress-themes/agency/',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('luzuk_real_estate_services_footer_copylink', array(
		'label'    => __('Copyright Link', 'real-estate-services'),
		'section'  => 'luzuk_real_estate_services_footer',
		'setting'  => 'luzuk_real_estate_services_footer_copylink',
		'type'     => 'text',
		'input_attrs' => array(
			'readonly' => 'readonly',
		),
	));

	$wp_customize->add_setting( 'luzuk_real_estate_services_footertext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_footertext_color', array(
		'label' => 'Text Color',
		'section' => 'luzuk_real_estate_services_footer',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_footerbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_footerbg_color', array(
		'label' => 'BG Color',
		'section' => 'luzuk_real_estate_services_footer',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_footercopyright_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_footercopyright_color', array(
		'label' => 'Copyright Color',
		'section' => 'luzuk_real_estate_services_footer',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_footercopyrightbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_footercopyrightbrd_color', array(
		'label' => 'Border Color',
		'section' => 'luzuk_real_estate_services_footer',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_footerscrolltotoptext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_footerscrolltotoptext_color', array(
		'label' => 'Scroll To Top Text Color',
		'section' => 'luzuk_real_estate_services_footer',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_footerscrolltotopbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_footerscrolltotopbg_color', array(
		'label' => 'Scroll To Top BG Color',
		'section' => 'luzuk_real_estate_services_footer',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_footerscrolltotoptexthover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_footerscrolltotoptexthover_color', array(
		'label' => 'Scroll To Top Text Hover Color',
		'section' => 'luzuk_real_estate_services_footer',
	)));

	$wp_customize->add_setting( 'luzuk_real_estate_services_footerscrolltotophover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_real_estate_services_footerscrolltotophover_color', array(
		'label' => 'Scroll To Top Hover Color',
		'section' => 'luzuk_real_estate_services_footer',
	)));




	

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'luzuk_real_estate_services_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'luzuk_real_estate_services_customize_partial_blogdescription',
	) );
}
add_action( 'customize_register', 'luzuk_real_estate_services_customize_register' );

function luzuk_real_estate_services_customize_partial_blogname() {
	bloginfo( 'name' );
}

function luzuk_real_estate_services_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

if (class_exists('WP_Customize_Control')) {

   	class Luzuk_Real_Estate_Services_Fontawesome_Icon_Chooser extends WP_Customize_Control {

      	public $type = 'icon';

      	public function render_content() { ?>
	     	<label>
	            <span class="customize-control-title">
	               <?php echo esc_html($this->label); ?>
	            </span>

	            <?php if ($this->description) { ?>
	                <span class="description customize-control-description">
	                   <?php echo wp_kses_post($this->description); ?>
	                </span>
	            <?php } ?>

	            <div class="real-estate-services-selected-icon">
	                <i class="fa <?php echo esc_attr($this->value()); ?>"></i>
	                <span><i class="fa fa-angle-down"></i></span>
	            </div>

	            <ul class="real-estate-services-icon-list clearfix">
	                <?php
	                $luzuk_real_estate_services_font_awesome_icon_array = luzuk_real_estate_services_font_awesome_icon_array();
	                foreach ($luzuk_real_estate_services_font_awesome_icon_array as $luzuk_real_estate_services_font_awesome_icon) {
	                   $icon_class = $this->value() == $luzuk_real_estate_services_font_awesome_icon ? 'icon-active' : '';
	                   echo '<li class=' . esc_attr($icon_class) . '><i class="' . esc_attr($luzuk_real_estate_services_font_awesome_icon) . '"></i></li>';
	                }
	                ?>
	            </ul>
	            <input type="hidden" value="<?php $this->value(); ?>" <?php $this->link(); ?> />
	        </label>
	        <?php
      	}
  	}
}
function luzuk_real_estate_services_customizer_script() {
   wp_enqueue_style( 'font-awesome-1', esc_url(get_template_directory_uri()).'/assets/css/fontawesome-all.css');
}
add_action( 'customize_controls_enqueue_scripts', 'luzuk_real_estate_services_customizer_script' );